@@ -253,7 +253,7 @@ int Preferences::Config_Save()
     if (Config(__T("Custom")).empty()) Config(__T("Custom"))=__T("Example");
     if (Config(__T("CheckUpdate")).empty()) Config(__T("CheckUpdate"))=__T("1");
     if (Config(__T("ShellExtension")).empty()) Config(__T("ShellExtension"))=__T("1");
-    if (Config(__T("ShellExtension_Folder")).empty()) Config(__T("ShellExtension_Folder"))=__T("0");
+    if (Config(__T("ShellExtension_Folder")).empty()) Config(__T("ShellExtension_Folder"))=__T("1");
     if (Config(__T("ShellInfoTip")).empty()) Config(__T("ShellInfoTip"))=__T("0");
     if (Config(__T("ShowToolBar")).empty()) Config(__T("ShowToolBar"))=__T("1");
     if (Config(__T("ShowMenu")).empty()) Config(__T("ShowMenu"))=__T("1");
@@ -637,16 +637,20 @@ int Preferences::ExplorerShell()
         ".aud;AUDFile\r\n"
         ".aue;AUEFile\r\n"
         ".avi;AVIFile\r\n"
+        ".avif;AVIFFile\r\n"
+        ".avs;AVSFile\r\n"
         ".bdmv;BDMVFile\r\n"
         ".bmp;BMPFile\r\n"
         ".bms;BMPFile\r\n"
         ".braw;BRAWFile\r\n"
         ".caf;CAFFile\r\n"
         ".clpi;CLPIFile\r\n"
+        ".dat;DATFile\r\n"
         ".dde;DolbyEFile\r\n"
         ".divx;AVIFile\r\n"
         ".dpg;DPGFile\r\n"
         ".dff;DFFFile\r\n"
+        ".dsd;DSDFile\r\n"
         ".dsf;DSFFile\r\n"
         ".dts;DTSFile\r\n"
         ".dtshd;DTSFile\r\n"
@@ -669,6 +673,10 @@ int Preferences::ExplorerShell()
         ".h264;H264File\r\n"
         ".h3d;JPEGFile\r\n"
         ".hdmov;MOVFile\r\n"
+        ".heic;HEICFile\r\n"
+        ".heif;HEICFile\r\n"
+        ".iamf;IAMFFile\r\n"
+        ".ico;ICOFile\r\n"
         ".ifo;IfoFile\r\n"
         ".ism;ISMFile\r\n"
         ".isma;ISMAFile\r\n"
@@ -678,6 +686,7 @@ int Preferences::ExplorerShell()
         ".jpeg;JPEGFile\r\n"
         ".jpg;JPEGFile\r\n"
         ".jps;JPEGFile\r\n"
+        ".jxl;JPEGFile\r\n"
         ".m1s;mpegFile\r\n"
         ".m1t;mpegFile\r\n"
         ".m1v;mpegFile\r\n"
@@ -751,7 +760,8 @@ int Preferences::ExplorerShell()
         ".vro;VROFile\r\n"
         ".w64;W64File\r\n"
         ".wav;WAVFile\r\n"
-        ".webM;WebMFile\r\n"
+        ".webm;WebMFile\r\n"
+        ".webp;WebPFile\r\n"
         ".wma;WMAFile\r\n"
         ".wmv;WMVFile\r\n"
         ".wtv;WTVFile\r\n"
@@ -802,6 +812,46 @@ int Preferences::ExplorerShell()
         }
     }
 
+    //Controls for legacy shell extension
+    int32s LegacyShellExtension = Config.Read(__T("ShellExtension")).To_int32s();
+    int32s LegacyShellExtension_Folder = Config.Read(__T("ShellExtension_Folder")).To_int32s();
+
+    //Control writing registry for modern IExplorerCommand-based shell extension
+    bool ModernShellExtensionUsed = false;
+
+    //Check presence of modern IExplorerCommand-based shell extension and handle things accordingly
+    TRegistry* ModernReg = new TRegistry;
+    ModernReg->RootKey = HKEY_CLASSES_ROOT;
+    try {
+        //If modern shell extension is installed
+        if (ModernReg->OpenKeyReadOnly(__T("PackagedCom\\ClassIndex\\{20669675-B281-4C4F-94FB-CB6FD3995545}"))) {
+            LegacyShellExtension = 0;                           //Disable legacy shell extension
+            LegacyShellExtension_Folder = 0;                    //Disable legacy shell extension
+            ModernShellExtensionUsed = true;                    //Need to control modern shell extension
+            ModernReg->CloseKey();
+        }
+    } catch (...) {}
+    delete ModernReg;
+
+    //Control modern IExplorerCommand-based shell extension
+    if (ModernShellExtensionUsed) {
+        TRegistry* ModernShellExtension = new TRegistry(KEY_WRITE);
+        try {
+            if (ModernShellExtension->OpenKey(__T("Software\\MediaArea\\MediaInfo"), true)) {
+                if (Config.Read(__T("ShellExtension")).To_int32s())
+                    ModernShellExtension->DeleteValue("ShellExtension");
+                else
+                    ModernShellExtension->WriteInteger("ShellExtension", 0);
+                if (Config.Read(__T("ShellExtension_Folder")).To_int32s())
+                    ModernShellExtension->DeleteValue("ShellExtension_Folder");
+                else
+                    ModernShellExtension->WriteInteger("ShellExtension_Folder", 0);
+                ModernShellExtension->CloseKey();
+            }
+        } catch (...) {}
+        delete ModernShellExtension;
+    }
+
     bool IsChanged=false;
     if ( MajorVersion>=6 //Windows Vista or more
      || (MajorVersion==5 && MinorVersion>=1)) //WinXP or more in 5.x family
@@ -857,28 +907,28 @@ int Preferences::ExplorerShell()
                 }
             }
         }
-        ExplorerShell_Edit("SystemFileAssociations\\audio", 0, IsChanged);
-        ExplorerShell_Edit("SystemFileAssociations\\Directory.Audio", 0, IsChanged);
-        ExplorerShell_Edit("SystemFileAssociations\\Directory.Video", 0, IsChanged);
-        ExplorerShell_Edit("SystemFileAssociations\\video", 0, IsChanged);
+        ExplorerShell_Edit("Software\\Classes\\SystemFileAssociations\\audio", 0, IsChanged);
+        ExplorerShell_Edit("Software\\Classes\\SystemFileAssociations\\Directory.Audio", 0, IsChanged);
+        ExplorerShell_Edit("Software\\Classes\\SystemFileAssociations\\Directory.Video", 0, IsChanged);
+        ExplorerShell_Edit("Software\\Classes\\SystemFileAssociations\\video", 0, IsChanged);
 
         //Adding/removing to SystemFileAssociations
-        int32s ShellExtension=Config.Read(__T("ShellExtension")).To_int32s();
+        int32s ShellExtension=LegacyShellExtension;
         for (size_t I1=0; I1<List.size(); I1++)
         {
             //Remove shell ext except "Folder"
             if (List(I1, 0)!=__T("Folder"))
                 ExplorerShell_Edit((__T("Software\\Classes\\SystemFileAssociations\\")+List(I1, 0)).c_str(), ShellExtension, IsChanged);
         }
-        ExplorerShell_Edit("Software\\Classes\\Directory", Config.Read(__T("ShellExtension_Folder")).To_int32s(), IsChanged);
+        ExplorerShell_Edit("Software\\Classes\\Directory", LegacyShellExtension_Folder, IsChanged);
     }
     else
     {
-        int32s ShellExtension=Config.Read(__T("ShellExtension")).To_int32s();
+        int32s ShellExtension=LegacyShellExtension;
         for (size_t I1=0; I1<List.size(); I1++)
         {
             if (List(I1, 0)==__T("Folder"))
-                ShellExtension=Config.Read(__T("ShellExtension_Folder")).To_int32s();
+                ShellExtension=LegacyShellExtension_Folder;
 
             //Open (or create) a extension. Create only if Shell extension is wanted
             if (Reg->OpenKey(List(I1, 0).c_str(), ShellExtension))
@@ -1250,27 +1300,41 @@ int Preferences::ShellToolTip()
     List=__T(
         ".264;H264File\r\n"
         ".3g2;mpeg4File\r\n"
-	".3ga;mpeg4File\r\n"
+        ".3ga;mpeg4File\r\n"
         ".3gp;mpeg4File\r\n"
-	".3gpa;mpeg4File\r\n"
+        ".3gpa;mpeg4File\r\n"
         ".3gpp;mpeg4File\r\n"
+        ".aa3;ATRACFile\r\n"
         ".aac;AACFile\r\n"
+        ".aacp;AACFile\r\n"
+        ".adts;AACFile\r\n"
         ".ac3;AC3File\r\n"
+        ".act;WAVFile\r\n"
+        ".aif;AIFFFile\r\n"
+        ".aifc;AIFFFile\r\n"
         ".aiff;AIFFFile\r\n"
         ".amr;AMRFile\r\n"
         ".ape;APEFile\r\n"
         ".asf;ASFFile\r\n"
+        ".at3;ATRACFile\r\n"
+        ".au;AUFile\r\n"
         ".aud;AUDFile\r\n"
         ".aue;AUEFile\r\n"
         ".avi;AVIFile\r\n"
+        ".avif;AVIFFile\r\n"
+        ".avs;AVSFile\r\n"
         ".bdmv;BDMVFile\r\n"
         ".bmp;BMPFile\r\n"
+        ".bms;BMPFile\r\n"
         ".braw;BRAWFile\r\n"
+        ".caf;CAFFile\r\n"
         ".clpi;CLPIFile\r\n"
+        ".dat;DATFile\r\n"
         ".dde;DolbyEFile\r\n"
         ".divx;AVIFile\r\n"
         ".dpg;DPGFile\r\n"
-        ".dsf;DFFFile\r\n"
+        ".dff;DFFFile\r\n"
+        ".dsd;DSDFile\r\n"
         ".dsf;DSFFile\r\n"
         ".dts;DTSFile\r\n"
         ".dtshd;DTSFile\r\n"
@@ -1279,15 +1343,24 @@ int Preferences::ShellToolTip()
         ".dvr-ms;DVRMSFile\r\n"
         ".eac3;EAC3File\r\n"
         ".evo;EVOFile\r\n"
+        ".f4a;mpeg4File\r\n"
+        ".f4b;mpeg4File\r\n"
         ".f4v;mpeg4File\r\n"
+        ".fla;FLACFile\r\n"
         ".flc;FLICFile\r\n"
         ".fli;FLICFile\r\n"
         ".flac;FLACFile\r\n"
         ".flv;FlashVideoFile\r\n"
         ".gvi;AVIFile\r\n"
         ".gif;GIFFile\r\n"
+        ".gis;GIFFile\r\n"
         ".h264;H264File\r\n"
+        ".h3d;JPEGFile\r\n"
         ".hdmov;MOVFile\r\n"
+        ".heic;HEICFile\r\n"
+        ".heif;HEICFile\r\n"
+        ".iamf;IAMFFile\r\n"
+        ".ico;ICOFile\r\n"
         ".ifo;IfoFile\r\n"
         ".ism;ISMFile\r\n"
         ".isma;ISMAFile\r\n"
@@ -1296,6 +1369,8 @@ int Preferences::ShellToolTip()
         ".jp2;JPEGFile\r\n"
         ".jpeg;JPEGFile\r\n"
         ".jpg;JPEGFile\r\n"
+        ".jps;JPEGFile\r\n"
+        ".jxl;JPEGFile\r\n"
         ".m1s;mpegFile\r\n"
         ".m1t;mpegFile\r\n"
         ".m1v;mpegFile\r\n"
@@ -1308,11 +1383,11 @@ int Preferences::ShellToolTip()
         ".m4b;mpeg4File\r\n"
         ".m4v;mpeg4File\r\n"
         ".mac;APEFile\r\n"
-        ".mlp;MLPFile\r\n"
         ".mk3d;MK3DFile\r\n"
         ".mka;MKAFile\r\n"
         ".mks;MKSFile\r\n"
         ".mkv;MKVFile\r\n"
+        ".mlp;MLPFile\r\n"
         ".mod;modFile\r\n"
         ".mov;MOVFile\r\n"
         ".mp+;mpcFile\r\n"
@@ -1328,6 +1403,7 @@ int Preferences::ShellToolTip()
         ".mpgx;mpegFile\r\n"
         ".mpls;MPLSFile\r\n"
         ".mpm;mpegFile\r\n"
+        ".mpo;JPEGFile\r\n"
         ".mpv;mpegFile\r\n"
         ".mts;mpegFile\r\n"
         ".mxf;MXFFile\r\n"
@@ -1336,29 +1412,43 @@ int Preferences::ShellToolTip()
         ".ogm;OGMFile\r\n"
         ".ogv;OGVFile\r\n"
         ".ogx;OGXFile\r\n"
+        ".oma;ATRACFile\r\n"
         ".opus;OpusFile\r\n"
         ".png;PNGFile\r\n"
+        ".pns;PNGFile\r\n"
         ".qcp;QCPFile\r\n"
         ".qt;QTFile\r\n"
         ".ra;RMFile\r\n"
         ".rm;RMFile\r\n"
         ".rmvb;FlashVideoFile\r\n"
+        ".shn;ShortenFile\r\n"
         ".smv;SMVFile\r\n"
+        ".spdif;SPDIFFile\r\n"
+        ".spx;SpeexFile\r\n"
         ".stl;STLFile\r\n"
         ".swf;FlashFile\r\n"
-        ".tak;TAKFile\r\n"
+        ".tak;TakVideoFile\r\n"
+        ".thd;THDFile\r\n"
+        ".thd+ac3;THDFile\r\n"
         ".tif;TIFFFile\r\n"
         ".tiff;TIFFFile\r\n"
+        ".tmf;mpegFile\r\n"
         ".tp;TPFile\r\n"
+        ".trec;mpeg4File\r\n"
         ".trp;TRPFile\r\n"
         ".ts;tsFile\r\n"
         ".tta;TTAFile\r\n"
+        ".ty;mpegFile\r\n"
         ".vob;mpegFile\r\n"
+        ".vqf;VQFFile\r\n"
+        ".vro;VROFile\r\n"
         ".w64;W64File\r\n"
         ".wav;WAVFile\r\n"
-        ".webM;WebMFile\r\n"
+        ".webm;WebMFile\r\n"
+        ".webp;WebPFile\r\n"
         ".wma;WMAFile\r\n"
         ".wmv;WMVFile\r\n"
+        ".wtv;WTVFile\r\n"
         ".wv;WCFile\r\n"
         ".wvc;WVCFile\r\n"
         ".y4m;Y4MFile\r\n"
