@@ -16,6 +16,7 @@
 #include "sheet.h"
 #include "configtreetext.h"
 #include "custom.h"
+#include "graphplugin.h"
 
 #include <QDropEvent>
 #include <QFileDialog>
@@ -32,6 +33,7 @@
 #include <QToolBar>
 #include <QMainWindow>
 #include <QMenuBar>
+#include <QWebEngineView>
 /*
 #include <qwt/qwt_plot.h>
 #include <qwt/qwt_plot_curve.h>
@@ -46,7 +48,7 @@ using namespace ZenLib;
 #define QString2wstring(_DATA) \
     Ztring().From_UTF8(_DATA.toUtf8())
 
-#define VERSION "24.11"
+#define VERSION "24.12"
 #if defined(_WIN32) && defined(WINAPI_FAMILY) && (WINAPI_FAMILY==WINAPI_FAMILY_APP) //UWP Application
 #include <QtPlatformHeaders/QWindowsWindowFunctions>
 #include <ZenLib/Os_Utils.h>
@@ -430,7 +432,7 @@ void MainWindow::openFiles(QStringList fileNames) {
     for(int i=0;i<fileNames.size();i++) {
         fileNames[i] = QDir::toNativeSeparators(fileNames[i]);
     }
-    C->Menu_File_Open_Files_Begin(settings->value("closeBeforeOpen",true).toBool(), false);
+    C->Menu_File_Open_Files_Begin(settings->value("closeBeforeOpen",true).toBool(), true);
     for (int Pos=0; Pos<fileNames.size(); Pos++)
         C->Menu_File_Open_Files_Continue(QString2wstring(fileNames[Pos]));
     openTimerInit();
@@ -480,7 +482,7 @@ void MainWindow::openDir(QString dirName) {
 
     //Configuring
     dirName = QDir::toNativeSeparators(dirName);
-    C->Menu_File_Open_Files_Begin(settings->value("closeBeforeOpen",true).toBool(), false);
+    C->Menu_File_Open_Files_Begin(settings->value("closeBeforeOpen",true).toBool(), true);
     C->Menu_File_Open_Directory(QString2wstring(dirName));
     openTimerInit();
 
@@ -499,6 +501,20 @@ void MainWindow::refreshDisplay() {
     ui->actionClose_All->setEnabled(C->Count_Get()>0);
     QDomDocument* xis;
 
+    C->Menu_Option_Preferences_Option(__T("Enable_Ffmpeg"), settings->value("enableFFmpeg",false).toBool() ? __T("1") : __T("0"));
+
+    switch(settings->value("displayCaptions",1).toInt()) {
+    case 0:
+        C->Menu_Option_Preferences_Option(__T("File_DisplayCaptions"),__T("Content"));
+        break;
+    case 1:
+        C->Menu_Option_Preferences_Option(__T("File_DisplayCaptions"),__T("Command"));
+        break;
+    case 2:
+        C->Menu_Option_Preferences_Option(__T("File_DisplayCaptions"),__T("Stream"));
+        break;
+    }
+
     if(C->Count_Get()<=0) {
 #if defined(_WIN32) && defined(WINAPI_FAMILY) && WINAPI_FAMILY==WINAPI_FAMILY_APP //UWP Application
         viewWidget = new QLabel(Tr("You must at least open 1 file.\nOpen a file or a directory."));
@@ -514,6 +530,8 @@ void MainWindow::refreshDisplay() {
             default:
             case VIEW_TEXT:
                 C->Menu_View_Text();
+                C->Menu_Option_Preferences_Option(__T("Inform_Version"), settings->value("informVersion",false).toBool() ? __T("1") : __T("0"));
+                C->Menu_Option_Preferences_Option(__T("Inform_Timestamp"), settings->value("informTimestamp",false).toBool() ? __T("1") : __T("0"));
                 viewWidget = new QTextBrowser();
                 ((QTextBrowser*)viewWidget)->setFont(font);
                 if(ConfigTreeText::getIndex()==0)
@@ -659,8 +677,12 @@ void MainWindow::refreshDisplay() {
                 break;
             case VIEW_HTML:
                 C->Menu_View_HTML();
-                viewWidget = new QTextBrowser();
-                ((QTextBrowser*)viewWidget)->setHtml(wstring2QString(C->Inform_Get()));
+                viewWidget = new QWebEngineView();
+                ((QWebEngineView*)viewWidget)->setHtml(wstring2QString(C->Inform_Get()));
+                break;
+            case VIEW_GRAPH:
+                viewWidget = new QWebEngineView();
+                ((QWebEngineView*)viewWidget)->setHtml(Generate_Graph_HTML(C, settings));
                 break;
             case VIEW_TREE:
                 C->Menu_View_Tree();
@@ -892,6 +914,7 @@ void MainWindow::applySettings() {
     ui->toolBar->setVisible(settings->value("showToolbar",true).toBool());
     ui->toolBar->setToolButtonStyle(Qt::ToolButtonStyle(settings->value("iconStyle",Qt::ToolButtonIconOnly).toInt()));
     ui->toolBar->setIconSize(settings->value("iconSize",QSize(32,32)).toSize());
+    C->Menu_Option_Preferences_Option(__T("LegacyStreamDisplay"), settings->value("legacyStreamDisplay",false).toBool() ? __T("1") : __T("0"));
 }
 
 void MainWindow::dropEvent(QDropEvent *event)
@@ -1108,6 +1131,10 @@ void MainWindow::on_actionExport_triggered()
             C->Menu_View_HTML();
             file.write(wstring2QString(C->Inform_Get()).toStdString().c_str());
             break;
+        case Export::GRAPH:
+            C->Menu_Option_Preferences_Inform(__T("Graph_Svg"));
+            file.write(wstring2QString(C->Inform_Get()).toStdString().c_str());
+            break;
         case Export::XML:
             C->Menu_View_XML();
             file.write(wstring2QString(C->Inform_Get()).toStdString().c_str());
