@@ -19,6 +19,9 @@
 #include "GUI/WxWidgets/GUI_Main_Tree.h"
 #include "GUI/WxWidgets/GUI_Main_HTML.h"
 #include "GUI/WxWidgets/GUI_Main_Text.h"
+#ifdef WX_PREFERENCES
+    #include "GUI/WxWidgets/GUI_Preferences.h"
+#endif
 #include "Common/Core.h"
 #include <wx/image.h>
 //---------------------------------------------------------------------------
@@ -33,6 +36,9 @@ enum
     ID_Menu_File_Open,
     ID_Menu_File_Open_Files,
     ID_Menu_File_Open_Directory,
+#ifdef WX_PREFERENCES
+    ID_Menu_File_Preferences,
+#endif
     ID_Menu_File_Quit,
     ID_Menu_View_Easy,
     ID_Menu_View_Sheet,
@@ -73,6 +79,9 @@ BEGIN_EVENT_TABLE(GUI_Main, wxFrame)
     //Menu
     EVT_MENU(ID_Menu_File_Open_Files,       GUI_Main::OnMenu_File_Open_Files)
     EVT_MENU(ID_Menu_File_Open_Directory,   GUI_Main::OnMenu_File_Open_Directory)
+    #ifdef WX_PREFERENCES
+        EVT_MENU(ID_Menu_File_Preferences,      GUI_Main::OnMenu_File_Preferences)
+    #endif
     EVT_MENU(wxID_EXIT,                     GUI_Main::OnMenu_File_Quit)
     EVT_MENU(ID_Menu_View_Easy,             GUI_Main::OnMenu_View_Easy)
     EVT_MENU(ID_Menu_View_Sheet,            GUI_Main::OnMenu_View_Sheet)
@@ -133,6 +142,9 @@ void GUI_Main::Menu_Create()
     //File
     Menu_File=new wxMenu;
                                  Menu_File->Append(ID_Menu_File_Open, __T("Open"), Menu_File_Open);
+    #ifdef WX_PREFERENCES
+        Menu_File_Preferences       =Menu_File->Append(ID_Menu_File_Preferences, __T("&Preferences"));
+    #endif
                                  Menu_File->AppendSeparator();
     Menu_File_Quit              =Menu_File->Append(wxID_EXIT, __T("E&xit\tAlt-X"), __T("Quit this program"));
 
@@ -222,6 +234,22 @@ void GUI_Main::OnMenu_File_Open_Files(wxCommandEvent& WXUNUSED(event))
     View->GUI_Refresh();
 }
 
+
+//---------------------------------------------------------------------------
+#ifdef WX_PREFERENCES
+void GUI_Main::OnMenu_File_Preferences(wxCommandEvent& WXUNUSED(event))
+{
+    if (!PreferencesEditor)
+    {
+        PreferencesEditor=new wxPreferencesEditor(wxT("Preferences"));
+        PreferencesEditor->AddPage(new GUI_Preferences_Page_General(this));
+        PreferencesEditor->AddPage(new GUI_Preferences_Page_Advanced(this));
+    }
+
+    PreferencesEditor->Show(this);
+}
+#endif
+
 //---------------------------------------------------------------------------
 void GUI_Main::OnMenu_File_Open_Directory(wxCommandEvent& WXUNUSED(event))
 {
